# AgentConnectorProxyStats

Statistics related to the transfer of data through an AgentConnector using its builtin proxy 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**overview** | [**AgentConnectorProxyRequestStats**](AgentConnectorProxyRequestStats.md) |  | 
**upstream_buffer_stats** | [**AgentConnectorUpstreamBufferStats**](AgentConnectorUpstreamBufferStats.md) |  | [optional] 
**start_time** | **datetime** | When the proxy last started. | [optional] 
**stop_time** | **datetime** | When the proxy last stopped. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


